Run-time configuration of Askbot — Askbot v0.7.43 documentation

# Askbot Project Documentation

Home | Ask Questions | Hire Us | Documentation | Contribute | Contact

# Run-time configuration of Askbot

Any of this can be done later via url /settings at your site - log in as a superuser and explore what is available.

Note

Probably the first two settings you should update are the Google Site verification Key for the sitemap and (if you want Google search engine crawl your site timely) the Google Analytics Key (if you wish to monitor the site traffic)

Google will be pinged each time question, answer or comment is saved or a question deleted and the site verification key is required for this to work. Please obtain the Site Verification Key at the Google Webmasters Tools site.

There are many more settings that can be changed at any time without restarting the site. More documentaition on this topic will be added in the near future.